
College Board Celebrity and Data Labs
=====================================

.. |Celebrity Lab| raw:: html

   <a href="https://apcentral.collegeboard.org/pdf/ap-computer-science-a-celebrity-lab-student-guide.pdf" target="_blank" style="text-decoration:underline">Celebrity Lab</a>


.. |Data Lab| raw:: html

   <a href="https://apcentral.collegeboard.org/pdf/ap-computer-science-a-data-lab-student-guide.pdf" target="_blank" style="text-decoration:underline">Data Lab</a>


You may have completed Activity 1 and 2 in the |Celebrity Lab| and |Data Lab|, new AP CSA Labs released in 2019, in Unit 5. The next activities in these labs, especially Activity 3, can be completed here for more practice with ArrayLists. The teacher guide and the code files are available in the AP Course Audit Portal. This page will eventually include tips to complete the labs.
